@@ -58,8 +58,7 @@ class ProxyManager:
                  num_executors=32,
                  executor_queue_size=1000,
                  verbose=False,
-                 new_session_fn=lambda: requests.Session(),
-                 loop=asyncio.get_event_loop()):
+                 new_session_fn=lambda: requests.Session(),):
         """
         Create a new proxy manager. The manager has the internal thread workers, so to make it properly
         work, use it as a context manager. ex) with ProxyManager(...) as proxy_manager: ...
@@ -76,7 +75,7 @@ class ProxyManager:
         self._proxy_info_dict = proxy_info_dict
         self._verbose = verbose
         self._new_session_fn = new_session_fn
-        self._loop = loop
+        self._loop = asyncio.get_event_loop()
 
         self._pool = self._init_pool(proxy_info_dict)
 
